##  How to Model Interfaces
  * To describe the integration between applications, SAP LeanIX makes use of the interface fact sheet.
  * The relationship between the applications and interfaces will be considered from a business point of view and less from a technical point of view.
  * The information that is exchanged will be classified by the use of data objects.
  * The IT components and interface relationship shows which technology supports which interfaces.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749df327a441014a4a5f330ce7cad46_LowRes.png)
This results in the visualization of interfaces in the data flow diagram and interface circle map report with:
  * Overview of the complexity of identifying interface clusters.
  * Filter by interface attributes or relations. For example, by a certain data object.
  * Filter by application attributes or relation. For example, by a certain user group like Region.
  * Diagrams allow you to include more interfaces, change the labels or layout, or add additional elements like boxes

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c974a7a441014a7e2d10839872a6b_LowRes.png)
Using the interface circle map, you can see all the interfaces and their relationships between applications.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27419d617a4410148b7e922848107a51_LowRes.png)
Interface Circle Map Report
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274baf187a441014bf2ee8026131bccb_LowRes.png)
Interface Circle Map with an Interface Selected
